==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/nb/ethiopic-amete-alem.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "nå",
	"field-quarter-relative+-1": "forrige kvartal",
	"field-weekday": "ukedag",
	"field-mon-narrow-relative+0": "denne ma.",
	"field-mon-narrow-relative+1": "neste ma.",
	"field-day-short-relative+0": "i dag",
	"field-day-short-relative+1": "i morgen",
	"field-day-short-relative+2": "i overmorgen",
	"field-wed-relative+0": "onsdag denne uken",
	"field-wed-relative+1": "onsdag neste uke",
	"eraNarrow": "TA0",
	"field-week-short": "uke",
	"field-year-short": "år",
	"field-tue-relative+-1": "tirsdag sist uke",
	"field-thu-narrow-relative+-1": "sist to.",
	"field-hour-relative+0": "denne timen",
	"field-quarter-narrow": "kv.",
	"field-fri-relative+-1": "fredag sist uke",
	"field-hour-short": "t",
	"field-wed-relative+-1": "onsdag sist uke",
	"field-mon-short-relative+-1": "sist man.",
	"field-day-short-relative+-1": "i går",
	"field-thu-relative+-1": "torsdag sist uke",
	"field-day-short-relative+-2": "i forgårs",
	"field-era": "tidsalder",
	"field-sat-narrow-relative+0": "denne lø.",
	"field-sat-narrow-relative+1": "neste lø.",
	"field-year": "år",
	"field-hour": "time",
	"field-sat-relative+0": "lørdag denne uken",
	"field-sat-relative+1": "lørdag neste uke",
	"field-sat-short-relative+-1": "sist lør.",
	"field-week-narrow-relative+-1": "forrige uke",
	"field-minute-narrow": "m",
	"field-day-relative+0": "i dag",
	"field-day-relative+1": "i morgen",
	"field-thu-relative+0": "torsdag denne uken",
	"field-day-relative+2": "i overmorgen",
	"field-mon-narrow-relative+-1": "sist ma.",
	"field-wed-narrow-relative+0": "denne on.",
	"field-thu-relative+1": "torsdag neste uke",
	"field-wed-narrow-relative+1": "neste on.",
	"field-mon-short-relative+0": "denne man.",
	"field-mon-short-relative+1": "neste man.",
	"field-wed-short-relative+-1": "sist ons.",
	"field-fri-narrow-relative+-1": "sist fr.",
	"field-hour-narrow": "t",
	"field-year-narrow": "år",
	"field-tue-short-relative+0": "denne tir.",
	"field-tue-short-relative+1": "neste tir.",
	"field-minute-short": "min",
	"field-day-narrow": "d.",
	"field-wed-short-relative+0": "denne ons.",
	"field-wed-short-relative+1": "neste ons.",
	"field-sun-relative+0": "søndag denne uken",
	"field-sun-relative+1": "søndag neste uke",
	"eraAbbr": [
		"0. t.a."
	],
	"field-minute": "minutt",
	"field-month-short": "mnd.",
	"field-dayperiod": "a.m./p.m.",
	"field-day-relative+-1": "i går",
	"field-day-relative+-2": "i forgårs",
	"field-minute-relative+0": "dette minuttet",
	"field-week-narrow": "u.",
	"field-wed-narrow-relative+-1": "sist on.",
	"field-day-short": "dag",
	"field-quarter-relative+0": "dette kvartalet",
	"field-quarter-relative+1": "neste kvartal",
	"field-fri-relative+0": "fredag denne uken",
	"field-fri-relative+1": "fredag neste uke",
	"field-day": "dag",
	"field-second-narrow": "s",
	"field-zone": "tidssone",
	"field-year-relative+-1": "i fjor",
	"field-month-relative+-1": "forrige måned",
	"field-thu-short-relative+0": "denne tor.",
	"field-thu-short-relative+1": "neste tor.",
	"field-quarter-narrow-relative+0": "dette kv.",
	"field-quarter-narrow-relative+1": "neste kv.",
	"eraNames": [
		"0. tidsalder"
	],
	"field-quarter": "kvartal",
	"field-month": "måned",
	"field-tue-relative+0": "tirsdag denne uken",
	"field-quarter-short-relative+0": "dette kv.",
	"field-tue-relative+1": "tirsdag neste uke",
	"field-quarter-short-relative+1": "neste kv.",
	"field-fri-narrow-relative+0": "denne fr.",
	"field-fri-narrow-relative+1": "neste fr.",
	"field-fri-short-relative+-1": "sist fre.",
	"field-sun-narrow-relative+-1": "sist sø.",
	"field-quarter-short-relative+-1": "forrige kv.",
	"field-week-narrow-relative+0": "denne uken",
	"field-week-narrow-relative+1": "neste uke",
	"field-sun-narrow-relative+0": "denne sø.",
	"field-thu-narrow-relative+0": "denne to.",
	"field-sun-narrow-relative+1": "neste sø.",
	"field-thu-narrow-relative+1": "neste to.",
	"field-tue-narrow-relative+0": "denne ti.",
	"field-mon-relative+0": "mandag denne uken",
	"field-tue-narrow-relative+1": "neste ti.",
	"field-week-short-relative+-1": "forrige uke",
	"field-mon-relative+1": "mandag neste uke",
	"field-tue-narrow-relative+-1": "sist ti.",
	"field-month-narrow-relative+0": "denne md.",
	"field-second-short": "sek",
	"field-month-narrow-relative+1": "neste md.",
	"field-second": "sekund",
	"field-fri-short-relative+0": "denne fre.",
	"field-sat-relative+-1": "lørdag sist uke",
	"field-fri-short-relative+1": "neste fre.",
	"field-sun-relative+-1": "søndag sist uke",
	"field-month-short-relative+0": "denne md.",
	"field-month-relative+0": "denne måneden",
	"field-quarter-narrow-relative+-1": "forrige kv.",
	"field-month-short-relative+1": "neste md.",
	"field-month-relative+1": "neste måned",
	"field-week-short-relative+0": "denne uken",
	"field-week-short-relative+1": "neste uke",
	"field-week": "uke",
	"field-sat-short-relative+0": "denne lør.",
	"field-sat-short-relative+1": "neste lør.",
	"field-year-relative+0": "i år",
	"field-week-relative+-1": "forrige uke",
	"field-year-relative+1": "neste år",
	"field-quarter-short": "kv.",
	"field-sun-short-relative+-1": "sist søn.",
	"field-thu-short-relative+-1": "sist tor.",
	"field-tue-short-relative+-1": "sist tir.",
	"field-mon-relative+-1": "mandag sist uke",
	"field-sat-narrow-relative+-1": "sist lø.",
	"field-month-narrow": "md.",
	"field-month-narrow-relative+-1": "forrige md.",
	"field-month-short-relative+-1": "forrige md.",
	"field-week-relative+0": "denne uken",
	"field-sun-short-relative+0": "denne søn.",
	"field-week-relative+1": "neste uke",
	"field-sun-short-relative+1": "neste søn."
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/nb/ethiopic-amete-alem.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "dette kv.",
	"field-quarter-short-relative+1": "neste kv.",
	"field-tue-relative+-1": "forrige tirsdag",
	"field-year": "år",
	"field-wed-relative+0": "onsdag",
	"field-wed-relative+1": "neste onsdag",
	"field-minute": "minutt",
	"field-month-narrow-relative+-1": "forrige md.",
	"field-tue-narrow-relative+0": "denne ti.",
	"field-tue-narrow-relative+1": "neste ti.",
	"field-thu-short-relative+0": "denne tor.",
	"field-day-short-relative+-1": "i går",
	"field-thu-short-relative+1": "neste tor.",
	"field-day-relative+0": "i dag",
	"field-day-short-relative+-2": "i forgårs",
	"field-day-relative+1": "i morgen",
	"field-week-narrow-relative+0": "denne uken",
	"field-day-relative+2": "i overmorgen",
	"field-week-narrow-relative+1": "neste uke",
	"field-wed-narrow-relative+-1": "sist on.",
	"field-year-narrow": "år",
	"field-era-short": "tidsalder",
	"field-year-narrow-relative+0": "i år",
	"field-tue-relative+0": "tirsdag",
	"field-year-narrow-relative+1": "neste år",
	"field-tue-relative+1": "neste tirsdag",
	"field-weekdayOfMonth": "ukedag i måneden",
	"field-second-short": "sek",
	"field-weekdayOfMonth-narrow": "uked. i md.",
	"field-week-relative+0": "denne uken",
	"field-month-relative+0": "denne måneden",
	"field-week-relative+1": "neste uke",
	"field-month-relative+1": "neste måned",
	"field-sun-narrow-relative+0": "denne sø.",
	"field-mon-short-relative+0": "denne man.",
	"field-sun-narrow-relative+1": "neste sø.",
	"field-mon-short-relative+1": "neste man.",
	"field-second-relative+0": "nå",
	"eraNames": [
		"0. tidsalder"
	],
	"field-weekOfMonth": "uke i måneden",
	"field-month-short": "mnd.",
	"field-day": "dag",
	"field-dayOfYear-short": "dag i året",
	"field-year-relative+-1": "i fjor",
	"field-sat-short-relative+-1": "sist lør.",
	"field-hour-relative+0": "denne timen",
	"field-second-short-relative+0": "nå",
	"field-wed-relative+-1": "forrige onsdag",
	"field-sat-narrow-relative+-1": "sist lø.",
	"field-second": "sekund",
	"field-quarter": "kvartal",
	"field-week-short": "uke",
	"field-day-narrow-relative+0": "i dag",
	"field-day-narrow-relative+1": "i morgen",
	"field-day-narrow-relative+2": "+2 d.",
	"field-tue-short-relative+0": "denne tir.",
	"field-tue-short-relative+1": "neste tir.",
	"field-month-short-relative+-1": "forrige md.",
	"field-mon-relative+-1": "forrige mandag",
	"field-month": "måned",
	"field-day-narrow": "d.",
	"field-minute-short": "min",
	"field-dayperiod": "a.m./p.m.",
	"field-sat-short-relative+0": "denne lør.",
	"field-sat-short-relative+1": "neste lør.",
	"eraAbbr": [
		"0. t.a."
	],
	"field-second-narrow": "s",
	"field-mon-relative+0": "mandag",
	"field-mon-relative+1": "neste mandag",
	"field-day-narrow-relative+-1": "i går",
	"field-year-short": "år",
	"field-day-narrow-relative+-2": "-2 d.",
	"field-quarter-relative+-1": "forrige kvartal",
	"field-dayperiod-narrow": "am/pm",
	"field-week-narrow-relative+-1": "forrige uke",
	"field-dayOfYear": "dag i året",
	"field-sat-relative+-1": "forrige lørdag",
	"field-hour": "time",
	"field-month-relative+-1": "forrige måned",
	"field-quarter-short": "kv.",
	"field-sat-narrow-relative+0": "denne lø.",
	"field-fri-relative+0": "fredag",
	"field-sat-narrow-relative+1": "neste lø.",
	"field-fri-relative+1": "neste fredag",
	"field-month-narrow-relative+0": "denne md.",
	"field-month-narrow-relative+1": "neste md.",
	"field-sun-short-relative+0": "denne søn.",
	"field-sun-short-relative+1": "neste søn.",
	"field-week-relative+-1": "forrige uke",
	"field-quarter-short-relative+-1": "forrige kv.",
	"field-quarter-relative+0": "dette kvartalet",
	"field-minute-relative+0": "dette minuttet",
	"field-quarter-relative+1": "neste kvartal",
	"field-wed-short-relative+-1": "sist ons.",
	"field-thu-short-relative+-1": "sist tor.",
	"field-year-narrow-relative+-1": "i fjor",
	"field-mon-narrow-relative+-1": "sist ma.",
	"field-thu-narrow-relative+-1": "sist to.",
	"field-tue-narrow-relative+-1": "sist ti.",
	"field-weekOfMonth-short": "uke i mnd.",
	"field-wed-short-relative+0": "denne ons.",
	"field-wed-short-relative+1": "neste ons.",
	"field-sun-relative+-1": "forrige søndag",
	"field-second-narrow-relative+0": "nå",
	"field-weekday": "ukedag",
	"field-day-short-relative+0": "i dag",
	"field-quarter-narrow-relative+0": "dette kv.",
	"field-sat-relative+0": "lørdag",
	"field-day-short-relative+1": "i morgen",
	"field-quarter-narrow-relative+1": "neste kv.",
	"field-sat-relative+1": "neste lørdag",
	"field-day-short-relative+2": "i overmorgen",
	"field-week-short-relative+0": "denne uken",
	"field-week-short-relative+1": "neste uke",
	"field-dayOfYear-narrow": "d. i året",
	"field-month-short-relative+0": "denne md.",
	"field-month-short-relative+1": "neste md.",
	"field-weekdayOfMonth-short": "uked. i mnd.",
	"field-zone-narrow": "tidssone",
	"field-thu-narrow-relative+0": "denne to.",
	"field-thu-narrow-relative+1": "neste to.",
	"field-sun-narrow-relative+-1": "sist sø.",
	"field-mon-short-relative+-1": "sist man.",
	"field-thu-relative+0": "torsdag",
	"field-thu-relative+1": "neste torsdag",
	"field-fri-short-relative+-1": "sist fre.",
	"field-thu-relative+-1": "forrige torsdag",
	"field-week": "uke",
	"field-wed-narrow-relative+0": "denne on.",
	"field-wed-narrow-relative+1": "neste on.",
	"field-quarter-narrow-relative+-1": "forrige kv.",
	"field-year-short-relative+0": "i år",
	"field-dayperiod-short": "am/pm",
	"field-year-short-relative+1": "neste år",
	"field-fri-short-relative+0": "denne fre.",
	"field-fri-short-relative+1": "neste fre.",
	"field-week-short-relative+-1": "forrige uke",
	"field-hour-short": "t",
	"field-zone-short": "tidssone",
	"field-month-narrow": "md.",
	"field-hour-narrow": "t",
	"field-fri-narrow-relative+-1": "sist fr.",
	"field-year-relative+0": "i år",
	"field-year-relative+1": "neste år",
	"field-era-narrow": "tidsalder",
	"field-fri-relative+-1": "forrige fredag",
	"eraNarrow": "TA0",
	"field-tue-short-relative+-1": "sist tir.",
	"field-minute-narrow": "m",
	"field-mon-narrow-relative+0": "denne ma.",
	"field-mon-narrow-relative+1": "neste ma.",
	"field-year-short-relative+-1": "i fjor",
	"field-zone": "tidssone",
	"field-weekOfMonth-narrow": "uke i md.",
	"field-weekday-narrow": "uked.",
	"field-quarter-narrow": "kv.",
	"field-sun-short-relative+-1": "sist søn.",
	"field-day-relative+-1": "i går",
	"field-day-relative+-2": "i forgårs",
	"field-weekday-short": "ukedag",
	"field-sun-relative+0": "søndag",
	"field-sun-relative+1": "neste søndag",
	"field-day-short": "dag",
	"field-week-narrow": "u.",
	"field-era": "tidsalder",
	"field-fri-narrow-relative+0": "denne fr.",
	"field-fri-narrow-relative+1": "neste fr."
}
//end v1.x content
);
